/* Python binding for GtkLevelHold
 * Copyright (C) 1999 Eric S. Tiedemann (est@hyperreal.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <math.h>
#include <assert.h>

#include <python1.5/Python.h>
#include <pygtk/pygtk.h>

#include "gtklevelhold.h"

typedef PyObject *(*PGN)(GtkObject *go);
static PGN pgn;

static PyObject *
pygtklh_new(PyObject *self, PyObject *args)
{
  PyObject *pglht, *pglhw;
  PyObject *o;
  GtkObject *adj;
  GtkWidget *d;
  int h, w, opts, levels;
  double hardhold;
  
  if (!PyArg_ParseTuple(args, "iiiid", &h, &w, &opts, &levels, &hardhold))
    return 0;

  d = gtk_level_hold_new(h, w, opts, levels, hardhold);

  if (!d)
    return 0;

  return pgn(GTK_OBJECT(d));
}

/* !!! need to clean up nicely on failure */
static PyObject *
pygtklh_set(PyObject *self, PyObject *args)
{
  PyObject *pglht, *pglhw;
  PyObject *o;
  GtkObject *adj;
  double val;

  if (!PyArg_ParseTuple(args, "Od", &o, &val))
    return 0;

  gtk_level_hold_set((GtkLevelHold *) (((PyGtk_Object *) o)->obj), val);

  Py_INCREF(Py_None);

  return Py_None;
}

static PyMethodDef pygtklhMethods[] =
{
  {"lh", pygtklh_new, METH_VARARGS},
  {"set", pygtklh_set, METH_VARARGS},
  {0, 0, 0}
};

void
init_pygtklevelhold()
{
  PyObject *_gtkmod, *_gtkmodd, *_private, *pgncobj;

  if (!(_gtkmod = PyImport_ImportModule("_gtk")))
    Py_FatalError("couldn't import _gtk");
  if (!(_gtkmodd = PyModule_GetDict(_gtkmod)))
    Py_FatalError("couldn't get _gtk's dictionary");
  if (!(_private = PyDict_GetItemString(_gtkmodd, "_private")))
    Py_FatalError("couldn't get _gtk._private");
  if (!(pgncobj = PyDict_GetItemString(_private, "PyGtk_New")))
    Py_FatalError("couldn't get _gtk._private.PyGtk_New");
  if (! PyCObject_Check(pgncobj))
    Py_FatalError("_gtk._private.PyGtk_New isn't a cobj");

  pgn = (PGN) PyCObject_AsVoidPtr(pgncobj);

  Py_InitModule("_pygtklevelhold", pygtklhMethods);
}
